@@ -18,13 +18,13 @@ HTML site.
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
-B<TODO: FILL IN>
+See L<HTML::Spelling::Site::Checker> .
 
-For now, see the example code on L<https://bitbucket.org/shlomif/shlomi-fish-homepage> .
+And also see the example code on L<https://bitbucket.org/shlomif/shlomi-fish-homepage> .
 
 =head1 DESCRIPTION
 
@@ -33,6 +33,13 @@ duplicate functionality for spell checking my web-sites. Currently
 documentation is somewhat lacking and the modules could use some extra
 automated tests, but I'm anxious to get something out the door.
 
+=head1 SEE ALSO
+
+L<Test::HTML::Spelling> - possibly somewhat less generic than
+HTML::Spelling::Site and can also only handle one file at the time. Note that
+I contributed a little to it, but only after I started working on the code
+that became this framework.
+
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
